#
# spec file for package rmt-server
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define app_dir      %{_datadir}/rmt
%define lib_dir      %{_libdir}/rmt
%define data_dir     %{_localstatedir}/lib/rmt
%define conf_dir     %{_sysconfdir}/rmt
%define rmt_user     _rmt
%define rmt_group    nginx
%define ruby_version %{rb_default_ruby_suffix}

Name:           rmt-server
Version:        2.3.1
Release:        lp151.2.3.1
Summary:        Repository mirroring tool and registration proxy for SCC
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Proxy
URL:            https://software.opensuse.org/package/rmt-server
Source0:        %{name}-%{version}.tar.bz2
Source1:        rmt-server-rpmlintrc
Source2:        rmt.conf
Source3:        rmt-cli.8.gz
BuildRequires:  %{ruby_version}
BuildRequires:  %{ruby_version}-devel
BuildRequires:  %{rubygem bundler}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  libcurl-devel
BuildRequires:  libffi-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  systemd
Requires:       gpg2
Requires:       mariadb
Requires:       nginx
Requires:       rmt-server-configuration
Requires(post): %{ruby_version}
Requires(post): %{rubygem bundler}
Requires(post): shadow
Requires(post): timezone
Requires(post): util-linux
Conflicts:      yast2-rmt < 1.0.3
Recommends:     yast2-rmt >= 1.0.3
Recommends:     rmt-server-config
# Does not build for i586 and s390 and is not supported on those architectures
ExcludeArch:    %{ix86} s390

%description
This package provides a mirroring tool for RPM repositories and a registration
proxy for the SUSE Customer Center (SCC).

As registration is required for SUSE products, the registration proxy allows
one to register SUSE products within a private network.

It's possible to mirror SUSE, as well as openSUSE and other RPM repositories.
SCC organization credentials are required to synchronize SUSE products,
subscription information, and to mirror SUSE repositories.

RMT supersedes the main functionality of SMT in SLES 15.

%package config
Summary:        RMT default configuration
Group:          Productivity/Networking/Web/Proxy
Requires:       rmt-server = %version
Provides:       rmt-server-configuration
Conflicts:      rmt-server-configuration

%description config
Summary:        Default nginx configuration for RMT.

%package pubcloud
Summary:        RMT pubcloud extensions
Group:          Productivity/Networking/Web/Proxy
Requires:       rmt-server = %version
Provides:       rmt-server-configuration
Conflicts:      rmt-server-configuration

%description pubcloud
This package extends the basic RMT functionality with capabilities
required for public cloud environments.

%prep
cp -p %{SOURCE2} .

%setup -q
sed -i '1 s|/usr/bin/env\ ruby|/usr/bin/ruby.%{ruby_version}|' bin/*

%build
bundle.%{ruby_version} install %{?jobs:--jobs %{jobs}} --without test development --deployment --standalone

%install
mkdir -p %{buildroot}%{data_dir}
mkdir -p %{buildroot}%{lib_dir}
mkdir -p %{buildroot}%{app_dir}
mkdir -p %{buildroot}%{conf_dir}/ssl
mkdir -p %{buildroot}%{data_dir}/regsharing

mv tmp %{buildroot}%{data_dir}
mkdir %{buildroot}%{data_dir}/public
mv public/repo %{buildroot}%{data_dir}/public/
mv public/suma %{buildroot}%{data_dir}/public/
mv vendor %{buildroot}%{lib_dir}

cp -ar . %{buildroot}%{app_dir}
ln -s %{data_dir}/tmp %{buildroot}%{app_dir}/tmp
ln -s %{data_dir}/public/repo %{buildroot}%{app_dir}/public/repo
ln -s %{data_dir}/public/suma %{buildroot}%{app_dir}/public/suma
mkdir -p %{buildroot}%{_bindir}
ln -s %{app_dir}/bin/rmt-cli %{buildroot}%{_bindir}
ln -s %{app_dir}/bin/rmt-data-import %{buildroot}%{_bindir}/rmt-data-import
ln -s %{app_dir}/bin/rmt-test-regsharing %{buildroot}%{_bindir}
install -D -m 644 %{_sourcedir}/rmt-cli.8.gz %{buildroot}%{_mandir}/man8/rmt-cli.8.gz

# systemd
mkdir -p %{buildroot}%{_unitdir}

install -m 444 package/files/systemd/rmt-server-mirror.timer %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-sync.timer %{buildroot}%{_unitdir}

install -m 444 package/files/systemd/rmt-server-mirror.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-sync.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server.service %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server.target %{buildroot}%{_unitdir}
install -m 444 package/files/systemd/rmt-server-migration.service %{buildroot}%{_unitdir}
install -m 444 engines/registration_sharing/package/rmt-server-regsharing.service %{buildroot}%{_unitdir}
install -m 444 engines/registration_sharing/package/rmt-server-regsharing.timer %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_sbindir}
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-migration
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-mirror
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-sync
ln -fs %{_sbindir}/service %{buildroot}%{_sbindir}/rcrmt-server-regsharing

mkdir -p %{buildroot}%{_sysconfdir}
mv %{_builddir}/rmt.conf %{buildroot}%{_sysconfdir}/rmt.conf

# nginx
install -D -m 644 package/files/nginx/nginx-http.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-http.conf
install -D -m 644 package/files/nginx/nginx-https.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-https.conf

install -D -m 644 package/files/nginx-pubcloud/nginx-http.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-http.conf
install -D -m 644 package/files/nginx-pubcloud/nginx-https.conf %{buildroot}%{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-https.conf
install -D -m 644 package/files/nginx-pubcloud/auth-handler.conf %{buildroot}%{_sysconfdir}/nginx/rmt-auth.d/auth-handler.conf
install -D -m 644 package/files/nginx-pubcloud/auth-location.conf %{buildroot}%{_sysconfdir}/nginx/rmt-auth.d/auth-location.conf

sed -i -e '/BUNDLE_PATH: .*/cBUNDLE_PATH: "\/usr\/lib64\/rmt\/vendor\/bundle\/"' \
    -e 's/^BUNDLE_JOBS: .*/BUNDLE_JOBS: "1"/' \
    %{buildroot}%{app_dir}/.bundle/config

# supportconfig plugin
mkdir -p %{buildroot}%{_libexecdir}/supportconfig/plugins
install -D -m 544 support/rmt %{buildroot}%{_libexecdir}/supportconfig/plugins/rmt

# bash completion
install -D -m 644 package/files/rmt-cli_bash-completion.sh %{buildroot}%{_datadir}/bash-completion/completions/rmt-cli

install -D -m 644 package/files/rmt-server.reg %{buildroot}%{_sysconfdir}/slp.reg.d/rmt-server.reg

# cleanup of /usr/bin/env commands
grep -rl '\/usr\/bin\/env ruby' %{buildroot}%{lib_dir}/vendor/bundle/ruby | xargs \
    sed -i -e 's@\/usr\/bin\/env ruby.%{ruby_version}@\/usr\/bin\/ruby\.%{ruby_version}@g' \
    -e 's@\/usr\/bin\/env ruby@\/usr\/bin\/ruby\.%{ruby_version}@g'
grep -rl '\/usr\/bin\/env bash' %{buildroot}%{lib_dir}/vendor/bundle/ruby | xargs \
    sed -i -e 's@\/usr\/bin\/env bash@\/bin\/bash@g' \

# cleanup unneeded files
find %{buildroot}%{lib_dir} "(" -name "*.c" -o -name "*.h" -o -name .keep ")" -delete
find %{buildroot}%{app_dir} -name .keep -delete
find %{buildroot}%{data_dir} -name .keep -delete
rm -r  %{buildroot}%{lib_dir}/vendor/bundle/ruby/2.*.0/cache
rm -rf %{buildroot}%{lib_dir}/vendor/cache
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/doc
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/examples
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/samples
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/test
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/ports
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/ext
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/bin
rm -rf %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/spec
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/*/.gitignore
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/extensions/*/*/*/gem_make.out
rm -f %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/extensions/*/*/*/mkmf.log
find %{buildroot}%{lib_dir}/vendor/bundle/ruby/*/gems/yard*/ -type f -exec chmod 644 -- {} +

%fdupes %{buildroot}/%{lib_dir}

%files
%attr(-,%{rmt_user},%{rmt_group}) %{app_dir}
%exclude %{app_dir}/engines/
%exclude %{app_dir}/package/
%attr(-,%{rmt_user},%{rmt_group}) %{data_dir}
%attr(-,%{rmt_user},%{rmt_group}) %{conf_dir}
%attr(-,%{rmt_user},%{rmt_group}) /var/lib/rmt
%dir %{_libexecdir}/supportconfig
%dir %{_libexecdir}/supportconfig/plugins
%dir %{_sysconfdir}/nginx
%dir %{_sysconfdir}/nginx/vhosts.d
%dir /var/lib/rmt
%dir %{_sysconfdir}/slp.reg.d
%config(noreplace) %attr(0640, %{rmt_user},root) %{_sysconfdir}/rmt.conf
%config(noreplace) %{_sysconfdir}/slp.reg.d/rmt-server.reg
%{_mandir}/man8/rmt-cli.8%{?ext_man}
%{_bindir}/rmt-cli
%{_bindir}/rmt-data-import
%{_sbindir}/rcrmt-server
%{_sbindir}/rcrmt-server-migration
%{_sbindir}/rcrmt-server-sync
%{_sbindir}/rcrmt-server-mirror
%{_unitdir}/rmt-server.target
%{_unitdir}/rmt-server.service
%{_unitdir}/rmt-server-migration.service
%{_unitdir}/rmt-server-mirror.service
%{_unitdir}/rmt-server-mirror.timer
%{_unitdir}/rmt-server-sync.service
%{_unitdir}/rmt-server-sync.timer
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/rmt-cli

%{_libdir}/rmt
%{_libexecdir}/supportconfig/plugins/rmt

%files config
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-http.conf
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-https.conf

%files pubcloud
%{_bindir}/rmt-test-regsharing
%attr(-,%{rmt_user},%{rmt_group}) %{app_dir}/engines/
%dir %{_sysconfdir}/nginx/rmt-auth.d/
%dir %attr(-,%{rmt_user},%{rmt_group}) %{data_dir}/regsharing
%exclude %{app_dir}/engines/registration_sharing/package/
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-http.conf
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/rmt-server-pubcloud-https.conf
%config(noreplace) %{_sysconfdir}/nginx/rmt-auth.d/auth-handler.conf
%config(noreplace) %{_sysconfdir}/nginx/rmt-auth.d/auth-location.conf

%{_sbindir}/rcrmt-server-regsharing
%{_unitdir}/rmt-server-regsharing.service
%{_unitdir}/rmt-server-regsharing.timer

%pre
getent group %{rmt_group} >/dev/null || %{_sbindir}/groupadd -r %{rmt_group}
getent passwd %{rmt_user} >/dev/null || \
	%{_sbindir}/useradd -g %{rmt_group} -s /bin/false -r \
	-c "user for RMT" -d %{app_dir} %{rmt_user}
%service_add_pre rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service

%post
%service_add_post rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service
cd %{_datadir}/rmt && runuser -u %{rmt_user} -g %{rmt_group} -- bin/rails secrets:setup >/dev/null
cd %{_datadir}/rmt && runuser -u %{rmt_user} -g %{rmt_group} -- bin/rails runner -e production "Rails::Secrets.write({'production' => {'secret_key_base' => SecureRandom.hex(64)}}.to_yaml)" >/dev/null

# Run only on install
if [ $1 -eq 1 ]; then
  echo "Please run the YaST RMT module (or 'yast2 rmt' from the command line) to complete the configuration of your RMT" >> /dev/stdout
fi

# Run only on upgrade
if [ $1 -eq 2 ]; then
  if [ -f %{app_dir}/ssl/rmt-ca.crt ]; then
    mv %{app_dir}/ssl/* %{conf_dir}/ssl
    echo "RMT SSL configuration has been moved to a new location: %{conf_dir}/ssl"
  fi
  if [ -f %{app_dir}/config/system_uuid ]; then
    mv %{app_dir}/config/system_uuid /var/lib/rmt/system_uuid
  fi
fi

%preun
%service_del_preun rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service

%postun
%service_del_postun rmt-server.target rmt-server.service rmt-server-migration.service rmt-server-mirror.service rmt-server-sync.service

%posttrans
/usr/bin/systemctl reload nginx.service

%pre pubcloud
%service_add_pre rmt-server-regsharing.service

%post pubcloud
%service_add_post rmt-server-regsharing.service

%preun pubcloud
%service_del_preun rmt-server-regsharing.service

%postun pubcloud
%service_del_postun rmt-server-regsharing.service

%posttrans pubcloud
/usr/bin/systemctl try-restart rmt-server.service

%changelog
* Fri Jul  5 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.3.1
- Fix mirroring logic when errors are encountered (bsc#1140492)
- Refactor RMT::Mirror to download metadata/licenses in parallel
* Mon Jul  1 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.3.0
- Check repo metadata GPG signatures during mirroring (bsc#1132690)
- Add rmt-server-config subpackage with nginx configs (fate#327816, bsc#1136081)
* Wed Jun 26 2019 Serhii Kotov <skotov@suse.com>
- Version 2.2.1
- Fix dependency to removed boot_cli_i18n file (bsc#1136020)
* Fri Jun 14 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.2.0
- Add `rmt-cli systems list` command to list registered systems
* Thu Jun  6 2019 Leon Schroeder <lschroeder@suse.com>
- Version 2.1.5
- Fix create UUID when system_uuid file empty (bsc#1138316)
* Wed May 15 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.1.4
- Fix duplicate nginx location in rmt-server-pubcloud (bsc#1135222)
* Mon May 13 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.1.3
- Mirror additional repos that were enabled during mirroring (bsc#1132690)
* Wed May  8 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.1.2
- Make service IDs consistent across different RMT instances (bsc#1134428)
* Mon May  6 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 2.1.1
- Make SMT data import scripts faster (bsc#1134190)
* Wed Apr 24 2019 Thomas Muntaner <tmuntaner@suse.com>
- Version 2.1.0
- Updated dependency nokogiri to 1.10.3 (CVE-2019-11068: bsc#1132160)
- Allow RMT registration to work under HTTP as well as HTTPS.
* Wed Apr 17 2019 tmuntaner@suse.com
- Version 2.0.0
- Breaking Change: Added headers to generated CSV files
* Tue Apr  2 2019 Serhii Kotov <skotov@suse.com>
- Version 1.2.8
- Offline migration from SLE 15 to SLE 15 SP1 will add Python2 module
* Thu Mar 21 2019 skotov@suse.com
- Version 1.2.7
- Online migrations will automatically add additional modules
  to the client systems depending on the base product
* Wed Mar 20 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 1.2.6
- Fix incorrect triggering of registration sharing (bsc#1129392)
- Add a script to manually test registration sharing
* Mon Mar 18 2019 tmuntaner@suse.com
- Version 1.2.5
- Updated rails to version 5.1.6.2 (CVE-2019-5419: bsc#1129271)
* Wed Mar 13 2019 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 1.2.4
- Supply log severity to journald
* Tue Mar 12 2019 Hernan Schmidt <hschmidt@suse.com>
- Version 1.2.3
- Fix license mirroring issue in some non-SUSE repositories (bsc#1128858)
* Mon Mar 11 2019 Thomas Muntaner <tmuntaner@suse.com>
- Added the ability to mirror the SUMA product tree.
* Thu Feb 21 2019 ikapelyukhin@suse.com
- Version 1.2.2
- Set CURLOPT_LOW_SPEED_LIMIT to prevent downloads from getting stuck (bsc#1107806)
- Removed use-ruby-2.5-in-rails.patch, use-ruby-2.5-in-rmt-data-import.patch and
  use-ruby-2.5-in-rmt-cli.patch as they are no longer needed.
* Mon Feb 18 2019 skotov@suse.com
- Version 1.2.1
- Truncate the RMT lockfile when writing a new PID (bsc#1125770)
- Zypper authentication plugin (fate#326629)
- Fix nested serializers in system/activations
- Fix HTTP vhost config
* Wed Jan 30 2019 ikapelyukhin@suse.com
- Version 1.2.0
- Legacy zypper XML endpoint for backward compatibility
  with SMT (fate#326629)
- Instance verification plugin in rmt-server-pubcloud (fate#326629)
* Tue Jan 22 2019 fschnizlein@suse.com
- Version 1.1.3
- Fix missing trailing slashes on custom repository import from SMT
  (bsc#1118745)
* Fri Jan 18 2019 skotov@suse.com
- Version 1.1.2
- Fix product version display (bsc#1117722)
* Tue Jan 15 2019 hschmidt@suse.com
- Cut version 1.1.1
* Tue Jan  8 2019 hschmidt@suse.com
- Fix some migration problems which caused some extensions / modules
  to be dropped. (bsc#1118584, bsc#1118579)
* Tue Dec 11 2018 tmuntaner@suse.com
- Fix listing of enabled for mirroring for non-mirrored products. (bsc#1102193)
* Tue Dec 11 2018 skotov@suse.com
- Include online migration paths into offline migration (bsc#1117106)
* Tue Dec 11 2018 skotov@suse.com
- Sync products that do not have base product (bsc#1109307)
* Fri Dec  7 2018 tmuntaner@suse.com
- Repository table using context relevant values instead of true and
  false.
* Thu Dec  6 2018 tmuntaner@suse.com
- Version 1.1.0
* Wed Dec  5 2018 tmuntaner@suse.com
- Bugfix: Alias commands in short form no longer raise an exception
  * remove -> rm -> r
  * list -> ls -> l
* Mon Dec  3 2018 tmuntaner@suse.com
- Added ability to enable/disable multiple repositories at the
  same time.
* Mon Dec  3 2018 tmuntaner@suse.com
- The command `rmt-cli products list` is more compact for smaller
  screens.
* Thu Nov 22 2018 hschmidt@suse.com
- Remove the "No product license found" message when mirroring.
  It's not useful for users, and it was just causing confusion,
  as many people mistook it for an error.
* Thu Nov 22 2018 wstephenson@suse.com
- Register to SLP if a server running on this host (bsc#1113760)
* Wed Nov 21 2018 skotov@suse.com
- Modules for migration are being sorted in the correct order
* Tue Nov 20 2018 tmuntaner@suse.com
- Added the ability to localize RMT
* Fri Nov  9 2018 sschricker@suse.de
- Add bash completion for rmt-cli
* Thu Nov  8 2018 tmuntaner@suse.com
- Added ability to enable/disable multiple products at the same time
* Tue Oct 30 2018 skotov@suse.com
- Version 1.0.7
- Import migration_extra attribute from SCC API
- Offline migrations will automatically add additional modules
  to the client systems depending on the base product
- Dependency gems security updates:
  - Update loofah to 2.2.3 (CVE-2018-16468)
  - Update rack to 2.0.6 (CVE-2018-16470)
  - Update nokogiri to 1.8.5 (CVE-2018-14404)
* Tue Oct 30 2018 tmuntaner@suse.com
- Added flag `--all-modules` to the `products enable` command to
  enable all free modules/extensions.
* Thu Sep 27 2018 ikapelyukhin@suse.com
- Improved exception handling when HTTP request fails due to
  a network or SSL validity issue
* Thu Aug  2 2018 fschnizlein@suse.com
- Version 1.0.6
- Change file paths to new locations to make RMT work with
  read-only rootfs (bsc#1102198)
- Change file permissions for rmt.conf (bsc#1104232)
- Nginx forwards to IPv4 address only (bsc#1107100)
* Thu Jul 19 2018 wstephenson@suse.com
- Version 1.0.5
- sort all list outputs alphabetically (bsc#1088680)
- Include 'last_seen_at' field in API systems output, for
  consistency with SCC
* Wed Jul  4 2018 fschueller@suse.com
- Version 1.0.4
- Only show post-install message on initial install
* Wed Jun 27 2018 ikapelyukhin@suse.com
- Version 1.0.3
- Fix duplicate migration paths (bsc#1097824)
* Tue Jun 19 2018 ikapelyukhin@suse.com
- Version 1.0.2
- Improved handling of errors during mirroring (bsc#1096967)
- Set correct permissions for product.license directory (bsc#1097367)
- Log version on service startup
* Fri Jun  1 2018 wstephenson@suse.com
- Version 1.0.1
- Use curl instead of wget in rmt-client-setup (bsc#1094348)
* Fri May 18 2018 skotov@suse.com
- Bump version to 1.0.0 (bsc#1093879)
- Make rmt-server recommend yast2-rmt
- Add the post-install message about running yast2-rmt
- Add new script rmt-data-import for migration from SMT to RMT
- Split off usage instruction into MANUAL.md
- Squash migrations into one
- Small improvements on CLI responses
- Rename clientSetup4RMT.sh => rmt-client-setup
- Add use-ruby-2.5-in-rmt-data-import.patch
* Fri May 11 2018 hschmidt@suse.com
- Don't check if a product has repos and that they are mirrored
  when deactivating.
  See: https://github.com/SUSE/rmt/pull/168
* Wed May  9 2018 wstephenson@suse.com
- Show custom repositories and product bindings in supportconfig
  plugin output
- Add CSV output option
  See: https://github.com/SUSE/rmt/pull/158
* Tue May  8 2018 tmuntaner@suse.com
- Rename of service files
  rmt.service -> rmt-server.service
  rmt-migration.service -> rmt-server-migration.service
  See: https://github.com/SUSE/rmt/pull/159
* Mon May  7 2018 tmuntaner@suse.com
- RMT server binds to 127.0.0.1, not 0.0.0.0
  See: https://github.com/SUSE/rmt/pull/158
* Mon May  7 2018 skotov@suse.com
- Lockfile handling with File#flock
  See: https://github.com/SUSE/rmt/pull/157
* Thu May  3 2018 skotov@suse.com
- Added lockfile feature for mirror, sync & import commands
* Thu May  3 2018 tmuntaner@suse.com
- Removed ability to change user/group through configuration (GH-144)
  See: https://github.com/SUSE/rmt/pull/154
* Thu Apr 26 2018 tmuntaner@suse.com
- Added supportconfig plugin
  See: https://github.com/SUSE/rmt/pull/146
- Rename organizations_products.json to organizations_products_unscoped.json (fixes bsc#1088687)
  See: https://github.com/SUSE/rmt/pull/151
- Improved log formatting in journald
  See: https://github.com/SUSE/rmt/pull/145
* Wed Apr 25 2018 tmuntaner@suse.com
- version 0.0.7
- Fixed offline repository sync with usb (bsc#1089038)
  See: https://github.com/SUSE/rmt/pull/147
- Removed unique index for uuid in HwInfo table
  See: https://github.com/SUSE/rmt/pull/142
- "rmt-cli products enable ..." enables recommended extensions in SLE 15
  See: https://github.com/SUSE/rmt/pull/141
- Added RMT header in requests for Connect API
  See: https://github.com/SUSE/rmt/pull/139
* Thu Apr 19 2018 skotov@suse.com
- version 0.0.6
- storing hardware info
  https://github.com/SUSE/rmt/pull/138
* Mon Apr  9 2018 tmuntaner@suse.com
- Only enable free modules in migrations for SLE 15
  https://github.com/SUSE/rmt/pull/132
* Mon Apr  9 2018 ikapelyukhin@suse.com
- version 0.0.5
- Allow access to the API only via HTTPS, add directories to store SSL
  keys & certificates, add clientSetup4RMT.sh script
  https://github.com/SUSE/rmt/pull/122
* Fri Apr  6 2018 hschmidt@suse.com
- Add the offline migration endpoint for upgrading major SLES versions.
  https://github.com/SUSE/rmt/pull/121
- Use the recommended systemd service type ("simple" instead of
  "forking").
  https://github.com/SUSE/rmt/pull/129
- Don't create a local licenses directory if the repo has no licenses.
  Closes bsc#1087707.
  https://github.com/SUSE/rmt/pull/126
- Don't allow duplicate activations to exist in the DB.
  https://github.com/SUSE/rmt/pull/119
* Fri Mar 23 2018 hschmidt@suse.com
- Version 0.0.4
- Fix nginx config to point to correct root location
  See: https://github.com/SUSE/rmt/issues/113
- Add message to help output about collecting feedback from users
- Only allow one activation to exist for a given system-service
  combination.
- Update loofah and rails-html-sanitizer gems due to CVEs.
- Add proper foreign key constraints where applicable.
* Thu Feb 22 2018 tschmidt@suse.com
- Do not build for s390 (bsc#1082150)
* Fri Feb 16 2018 tmuntaner@suse.com
- Use correct service for systemd timers
* Fri Feb 16 2018 tschmidt@suse.com
- RMT on SLE12 also uses ruby 2.5
  - Removed use-ruby-2.4-in-rails.patch and use-ruby-2.4-in-rmt-cli.patch as
    they are no longer needed.
* Wed Feb 14 2018 tmuntaner@suse.com
- Fixed systemd timers for SLES 12 and Leap
* Mon Feb 12 2018 tmuntaner@suse.com
- version 0.0.3
- Added nginx integration
- Added systemd timers for rmt-server-sync and rmt-server-mirror
- Added custom repository integration
* Wed Jan 24 2018 ikapelyukhin@suse.com
- version 0.0.2
- Use cached metadata when possible (bsc#1066669)
* Sat Dec 16 2017 bwiedemann@suse.com
- Dont package build logs to make build reproducible
* Wed Dec  6 2017 dimstar@opensuse.org
- Exclude Build for i586: does not build and is not supported on
  32bit intel archs.
* Thu Nov 30 2017 tschmidt@suse.com
- Change package name to `rmt-server` to not conflict with the unix tool `rmt`
* Mon Oct 16 2017 ikapelyukhin@suse.com
- Update summary and description
- Fix 'env-script-interpreter' rpmlint error
- Ignore 'env-script-interpreter' for bundled scripts
- Remove leftover .keep files
* Thu Oct 12 2017 jengelh@inai.de
- Replace %%__-type macro indirections.
- Do not ignore errors from useradd/groupadd.
- Avoid running fdupes over partition boundaries.
- Compact description, find-delete calls and %%systemd_* calls.
* Tue Jun  6 2017 ikapelyukhin@suse.com
- Initial version 0.0.1
